'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var umi = require('@metaplex-foundation/umi');
var umiWeb3jsAdapters = require('@metaplex-foundation/umi-web3js-adapters');
var ed25519 = require('@noble/ed25519');
var web3_js = require('@solana/web3.js');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var ed25519__namespace = /*#__PURE__*/_interopNamespace(ed25519);

function createWeb3JsEddsa() {
  const generateKeypair = () => umiWeb3jsAdapters.fromWeb3JsKeypair(web3_js.Keypair.generate());
  const createKeypairFromSecretKey = secretKey => umiWeb3jsAdapters.fromWeb3JsKeypair(web3_js.Keypair.fromSecretKey(secretKey));
  const createKeypairFromSeed = seed => umiWeb3jsAdapters.fromWeb3JsKeypair(web3_js.Keypair.fromSeed(seed));
  const isOnCurve = input => web3_js.PublicKey.isOnCurve(umiWeb3jsAdapters.toWeb3JsPublicKey(umi.publicKey(input)));
  const findPda = (programId, seeds) => {
    const [key, bump] = web3_js.PublicKey.findProgramAddressSync(seeds, umiWeb3jsAdapters.toWeb3JsPublicKey(umi.publicKey(programId)));
    return {
      ...umiWeb3jsAdapters.fromWeb3JsPublicKey(key),
      bump
    };
  };
  const sign = (message, keypair) => ed25519__namespace.sync.sign(message, keypair.secretKey.slice(0, 32));
  const verify = (message, signature, publicKey) => ed25519__namespace.sync.verify(signature, message, publicKey.bytes);
  return {
    generateKeypair,
    createKeypairFromSecretKey,
    createKeypairFromSeed,
    isOnCurve,
    findPda,
    sign,
    verify
  };
}

exports.createWeb3JsEddsa = createWeb3JsEddsa;
//# sourceMappingURL=createWeb3JsEddsa.cjs.map
